R/schemes.R
corr_wheel_schemes.Rd
Returns the names of the colour schemes bundled with the package, for use as the scheme argument of corr_wheel().
scheme
corr_wheel()
corr_wheel_schemes()
A character vector of scheme names.
corr_wheel_scheme(), corr_wheel()
corr_wheel_scheme()
corr_wheel_schemes() #> [1] "default" "colorblind" "ocean" "vivid" "alimetry"